@@ -441,5 +441,5 @@ if __name__ == '__main__':
     # query = {"total_operate_income": 0}
     # un_report_company_info = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
     # symbol_list = list(un_report_company_info['symbol'])
-    sync_company_base_info(['600753'])
+    sync_company_base_info(None)
     # group_by_industry()
