@@ -2,7 +2,7 @@ import sys
 import os
 
 file_path = os.path.abspath(__file__)
-end = file_path.index('mns') + 16
+end = file_path.index('mns') + 17
 project_path = file_path[0:end]
 sys.path.append(project_path)
 import mns_common.component.deal.deal_service_api as deal_service_api
@@ -21,7 +21,7 @@ def ths_auto_login():
 
 
 def auto_login():
-    # qmt_auto_login()
+    qmt_auto_login()
     time.sleep(5)
     ths_auto_login()
 
