@@ -96,7 +96,7 @@ def stock_sync_qfq_weekly():
     str_now_date = now_date.strftime('%Y-%m-%d')
     if date_handle_util.last_day_of_week(now_date):
         logger.info('同步每周行情数据(前复权):' + str_now_date)
-        daily_week_month_line_sync_api.sync_all_daily_data('weekly', 'qfq', 'stock_qfq_weekly', None)
+        daily_week_month_line_sync_api.sync_all_daily_data('weekly', 'qfq', 'stock_qfq_weekly', str_now_date)
 
 
 # # 定时同步每周交易行情数据(前复权)
@@ -106,7 +106,7 @@ def stock_sync_qfq_monthly():
     if date_handle_util.last_day_month(now_date):
         logger.info('同步每周行情数据(前复权):' + str_now_date)
         daily_week_month_line_sync_api.sync_all_daily_data('monthly', 'qfq', 'stock_qfq_monthly',
-                                                           None)
+                                                           str_now_date)
 
 
 #  当天实时数据备份
@@ -138,7 +138,7 @@ def stock_daily_sync_qfq():
     str_now_date = now_date.strftime('%Y-%m-%d')
     logger.info('同步每日行情数据(前复权):' + str_now_date)
     daily_week_month_line_sync_api.sync_all_daily_data('daily',
-                                                       'qfq', 'stock_qfq_daily', None)
+                                                       'qfq', 'stock_qfq_daily', str_now_date)
 
 
 # 同步当日k c x 高涨幅数据
